diff --git a/ryzom_api/tool_registry.php b/ryzom_api/tool_registry.php
new file mode 100644
index 0000000..57d7d8c
--- /dev/null
+++ b/ryzom_api/tool_registry.php
@@ -0,0 +1,160 @@
+<?php
+/* Copyright (C) 2009 Winch Gate Property Limited
+ *
+ * This file is part of ryzom_api.
+ * ryzom_api is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * ryzom_api is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with ryzom_api.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
+class registry
+	implements	ArrayAccess
+{
+	protected	$_tree = array(0 => null) ;
+	protected	$_current ;
+
+	static
+	public		function load($array)
+	{
+		$registry = new self ;
+		$registry->_tree = $array ;
+		$registry->cd('/') ;
+
+		return $registry ;
+	}
+
+	public		function __construct()
+	{
+		$ref = & $this->_tree ;
+		$this->_current = (object) array('ref' => &$ref) ;
+	}
+
+	public		function cd($path)
+	{
+		$current = & $this->_seek_node($path) ;
+		unset($this->_current->ref) ;
+		$this->_current->ref = & $current ;
+		return $this ;
+	}
+
+	public		function offsetExists($path)
+	{
+		try
+		{
+			$node = & $this->_seek_node($path) ;
+			return is_array($node) ;
+		}
+		catch(exception $e)
+		{
+			return false ;
+		}
+	}
+
+	public		function offsetGet($path)
+	{
+		$node = & $this->_seek_node($path) ;
+		return isset($node[0]) ? $node[0] : null ;
+	}
+
+	public		function offsetUnset($path)
+	{
+		$node = & $this->_seek_node($path) ;
+		$node = null ;
+	}
+
+	public		function offsetSet($path, $value)
+	{
+		$keys = $this->_explode_path($path) ;
+
+		// If it is absolute path
+		if(strpos($path, '/') === 0)
+		{
+			$node = & $this->_tree ;
+			array_shift($keys) ;
+		}
+		else
+			$node = & $this->_current->ref ;
+
+		// go in tree as deeper as we can
+		while(is_string($key = array_shift($keys)))
+		{
+			if(!empty($key) && isset($node[$key]) && is_array($node[$key]))
+			{
+				// reference swaping
+				unset($n) ;		$n = & $node[$key] ;
+				unset($node) ;	$node = & $n ;
+			}
+			else
+				break ;
+		}
+
+		// create branch if it doesn't exist
+		do
+		{
+			if(!empty($key))
+			{
+				$node[$key] = array(0 => null) ;
+				// reference swaping
+				unset($n) ;		$n = & $node[$key] ;
+				unset($node) ;	$node = & $n ;
+			}
+		}
+		while(is_string($key = array_shift($keys))) ;
+
+		$node[0] = $value ;
+	}
+
+	public		function childs($path = '')
+	{
+		$node = & $this->_seek_node($path) ;
+		return array_filter(array_keys($node), 'is_string') ;
+	}
+
+	protected	function & _seek_node($path)
+	{
+		$keys = $this->_explode_path($path) ;
+
+		if(strpos($path, '/') === 0)
+		{
+			$node = & $this->_tree ;
+			array_shift($keys) ;
+		}
+		else
+			$node = & $this->_current->ref ;
+
+		while(is_string($key = array_shift($keys)))
+		{
+			if(!empty($key))
+				if(isset($node[$key]) && is_array($node[$key]))
+				{
+					// reference swaping
+					unset($n) ;		$n = & $node[$key] ;
+					unset($node) ;	$node = & $n ;
+				}
+				else
+					throw new exception(sprintf('Couldn\'t path to (%s).', $path)) ;
+		}
+
+		return $node ;
+	}
+
+	protected	function _explode_path($path)
+	{
+		$keys = explode('/', $path) ;
+
+		if(count($keys) < 1)
+			throw new exception(sprintf('Invalid path "%s".', $path)) ;
+
+		return $keys ;
+	}
+}
+
